magneticalc.Wire_Widget.Wire_Widget

# ``magneticalc`.`Wire_Widget`.`Wire_Widget``

class documentation

`class Wire_Widget(QGroupBox2):`

Constructor: `Wire_Widget(gui)`

View In Hierarchy

Wire_Widget class.

Method | `__init__` | Populates the widget.
Method | `clear_rotational_symmetry` | Clears the rotational symmetry values.
Method | `clear_stretch` | Clears the stretch values.
Method | `on_table_cell_edited` | Gets called after a table cell has been edited.
Method | `on_table_row_added` | Gets called after a row has been added to the table.
Method | `on_table_row_deleted` | Gets called after a row has been deleted from the table.
Method | `reload` | Reloads the widget.
Method | `set_rotational_symmetry` | Handles changes to rotational symmetry transform parameters.
Method | `set_stretch` | Handles changes to stretch transform parameters.
Method | `set_wire` | Sets the wire. This will overwrite the currently set wire in the model. Any underscored parameter may be left set to None in order to load its default value.
Method | `update` | Updates the widget.
Method | `update_controls` | Updates the controls.
Method | `update_labels` | Updates the labels.
Method | `update_rotational_symmetry` | Updates the rotational symmetry controls.
Method | `update_stretch` | Updates the stretch controls.
Method | `update_table` | Populates the table.
Class Variable | `DcMax` | Undocumented
Class Variable | `DcMin` | Undocumented
Class Variable | `DcPrecision` | Undocumented
Class Variable | `DcStep` | Undocumented
Class Variable | `RotationalSymmetryCountMax` | Undocumented
Class Variable | `RotationalSymmetryCountMin` | Undocumented
Class Variable | `RotationalSymmetryOffsetMax` | Undocumented
Class Variable | `RotationalSymmetryOffsetMin` | Undocumented
Class Variable | `RotationalSymmetryOffsetPrecision` | Undocumented
Class Variable | `RotationalSymmetryOffsetStep` | Undocumented
Class Variable | `RotationalSymmetryRadiusMax` | Undocumented
Class Variable | `RotationalSymmetryRadiusMin` | Undocumented
Class Variable | `RotationalSymmetryRadiusPrecision` | Undocumented
Class Variable | `RotationalSymmetryRadiusStep` | Undocumented
Class Variable | `SlicerLimitMax` | Undocumented
Class Variable | `SlicerLimitMin` | Undocumented
Class Variable | `SlicerLimitPrecision` | Undocumented
Class Variable | `SlicerLimitStep` | Undocumented
Class Variable | `StretchMax` | Undocumented
Class Variable | `StretchMin` | Undocumented
Class Variable | `StretchPrecision` | Undocumented
Class Variable | `StretchStep` | Undocumented
Class Variable | `UnitsLabelWidth` | Undocumented
Instance Variable | `close_loop_checkbox` | Undocumented
Instance Variable | `dc_spinbox` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `rotational_symmetry_axis_combobox` | Undocumented
Instance Variable | `rotational_symmetry_count_spinbox` | Undocumented
Instance Variable | `rotational_symmetry_offset_spinbox` | Undocumented
Instance Variable | `rotational_symmetry_radius_spinbox` | Undocumented
Instance Variable | `sliced_total_label` | Undocumented
Instance Variable | `slicer_limit_spinbox` | Undocumented
Instance Variable | `stretch_spinbox` | Undocumented
Instance Variable | `table` | Undocumented
Instance Variable | `table_total_label` | Undocumented
Instance Variable | `transformed_total_label` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def clear_rotational_symmetry(self):

Clears the rotational symmetry values.

def clear_stretch(self):

Clears the stretch values.

def on_table_cell_edited(self, value: `float`, row: `int`, column: `int`):

Gets called after a table cell has been edited.

Parameters
value: `float` | Cell value
row: `int` | Row index
column: `int` | Column index

def on_table_row_added(self):

Gets called after a row has been added to the table.

def on_table_row_deleted(self, index: `int`):

Gets called after a row has been deleted from the table.

Parameters
index: `int` | Row index

def reload(self):

Reloads the widget.

def set_rotational_symmetry(self):

Handles changes to rotational symmetry transform parameters.

def set_stretch(self):

Handles changes to stretch transform parameters.

def set_wire(self, _points_: `list | np.ndarray | None` = None, _stretch_: `list | None` = None, _rotational_symmetry_: `dict | None` = None, _close_loop_: `bool | None` = None, _slicer_limit_: `float | None` = None, _dc_: `float | None` = None, invalidate: `bool` = True, recalculate: `bool` = True, readjust_sampling_volume: `bool` = True):

Sets the wire. This will overwrite the currently set wire in the model. Any underscored parameter may be left set to None in order to load its default value.

Note: Currently, only `stretch` and `rotational symmetry` controls are automatically updated by this function.

Parameters
_points_: `list | np.ndarray | None` | Points (List of 3D points)
_stretch_: `list | None` | XYZ stretch transform factors (3D point)
_rotational_symmetry_: `dict | None` | Dictionary for rotational symmetry transform
_close_loop_: `bool | None` | Enable to transform the wire into a closed loop (append first point)
_slicer_limit_: `float | None` | Slicer limit
_dc_: `float | None` | DC value
invalidate: `bool` | Enable to invalidate this model hierarchy level
recalculate: `bool` | Enable to trigger final recalculation
readjust_sampling_volume: `bool` | Enable to readjust sampling volume

def update(self):

Updates the widget.

def update_controls(self):

Updates the controls.

def update_labels(self):

Updates the labels.

def update_rotational_symmetry(self, rotational_symmetry: `dict`):

Updates the rotational symmetry controls.

Parameters
rotational_symmetry: `dict` | Dictionary

def update_stretch(self, stretch: `list`):

Updates the stretch controls.

Parameters
stretch: `list` | 3D point

def update_table(self):

Populates the table.

DcMax: `float` =

Undocumented

DcMin: `float` =

Undocumented

DcPrecision: `int` =

Undocumented

DcStep: `float` =

Undocumented

RotationalSymmetryCountMax: `int` =

Undocumented

RotationalSymmetryCountMin: `int` =

Undocumented

RotationalSymmetryOffsetMax: `int` =

Undocumented

RotationalSymmetryOffsetMin: `int` =

Undocumented

RotationalSymmetryOffsetPrecision: `int` =

Undocumented

RotationalSymmetryOffsetStep: `int` =

Undocumented

RotationalSymmetryRadiusMax: `int` =

Undocumented

RotationalSymmetryRadiusMin: `int` =

Undocumented

RotationalSymmetryRadiusPrecision: `int` =

Undocumented

RotationalSymmetryRadiusStep: `float` =

Undocumented

SlicerLimitMax: `float` =

Undocumented

SlicerLimitMin: `float` =

Undocumented

SlicerLimitPrecision: `int` =

Undocumented

SlicerLimitStep: `float` =

Undocumented

StretchMax: `int` =

Undocumented

StretchMin: `int` =

Undocumented

StretchPrecision: `int` =

Undocumented

StretchStep: `float` =

Undocumented

UnitsLabelWidth: `int` =

Undocumented

close_loop_checkbox =

Undocumented

dc_spinbox =

Undocumented

gui =

Undocumented

rotational_symmetry_axis_combobox =

Undocumented

rotational_symmetry_count_spinbox =

Undocumented

rotational_symmetry_offset_spinbox =

Undocumented

rotational_symmetry_radius_spinbox =

Undocumented

sliced_total_label =

Undocumented

slicer_limit_spinbox =

Undocumented

stretch_spinbox: `list` =

Undocumented

table =

Undocumented

table_total_label =

Undocumented

transformed_total_label =

Undocumented